/* $RCSfile$
 * $Author: hansonr $
 * $Date: 2008-11-27 09:48:39 -0600 (Thu, 27 Nov 2008) $
 * $Revision: 10382 $
 *
 * Copyright (C) 2002-2005  The Jmol Development Team
 *
 * Contact: jmol-developers@lists.sf.net
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */

package org.jmol.api;

import org.jmol.constant.EnumCallback;

public interface JmolCallbackListener {
/*
 * These methods specifically provide notification from 
 * Viewer.StatusManager for callback methods.
 * 
 * See Jmol.java for implementation examples.
 * 
 */

  public void setCallbackFunction(String callbackType, String callbackFunction);
  
  public void notifyCallback(EnumCallback message, Object[] data);

  public boolean notifyEnabled(EnumCallback type);

}
